"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.persistenceLayer = exports.PersistenceLayer = void 0;
const eventemitter3_1 = require("eventemitter3");
const typeorm_1 = require("typeorm");
const Event_1 = require("./Event");
const debug_1 = __importDefault(require("debug"));
const log = (0, debug_1.default)("sourced-repo-typeorm");
class PersistenceLayer extends eventemitter3_1.EventEmitter {
    constructor() {
        super();
        this.connection = null;
        this.connectionOptions = null;
    }
    connect(options) {
        return __awaiter(this, void 0, void 0, function* () {
            log("⏳ Initializing connection via typeorm...");
            Object.assign(options, {
                entities: [Event_1.Event],
                synchronize: typeof options.synchronize !== "undefined" ? options.synchronize : true,
            });
            this.connectionOptions = options;
            try {
                this.connection = yield (0, typeorm_1.createConnection)(this.connectionOptions);
                log("✅ Initialized connection via typeorm");
            }
            catch (err) {
                log("🚨 PersistenceLayer Connection Error. Please make sure PersistenceLayer is running: ", err);
                throw err;
            }
            return this.connection;
        });
    }
    disconnect() {
        return __awaiter(this, void 0, void 0, function* () {
            log("⏳ Closing sourced typeorm connection... ");
            try {
                yield this.connection.close();
            }
            catch (err) {
                log("🚨 Error while closing PersistenceLayer Connection:", err);
                throw err;
            }
            log("✅ Closed sourced typeorm connection");
        });
    }
}
exports.PersistenceLayer = PersistenceLayer;
exports.persistenceLayer = new PersistenceLayer();
