var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { EventEmitter } from "eventemitter3";
import { createConnection } from "typeorm";
import { Event } from "./Event";
import debug from "debug";
const log = debug("sourced-repo-typeorm");
export class PersistenceLayer extends EventEmitter {
    constructor() {
        super();
        this.connection = null;
        this.connectionOptions = null;
    }
    connect(options) {
        return __awaiter(this, void 0, void 0, function* () {
            log("⏳ Initializing connection via typeorm...");
            Object.assign(options, {
                entities: [Event],
                synchronize: typeof options.synchronize !== "undefined" ? options.synchronize : true,
            });
            this.connectionOptions = options;
            try {
                this.connection = yield createConnection(this.connectionOptions);
                log("✅ Initialized connection via typeorm");
            }
            catch (err) {
                log("🚨 PersistenceLayer Connection Error. Please make sure PersistenceLayer is running: ", err);
                throw err;
            }
            return this.connection;
        });
    }
    disconnect() {
        return __awaiter(this, void 0, void 0, function* () {
            log("⏳ Closing sourced typeorm connection... ");
            try {
                yield this.connection.close();
            }
            catch (err) {
                log("🚨 Error while closing PersistenceLayer Connection:", err);
                throw err;
            }
            log("✅ Closed sourced typeorm connection");
        });
    }
}
export const persistenceLayer = new PersistenceLayer();
